# mula - Moodle Update for Lazy Admins

## Install using pip from git

```bash
pip install git+https://github.com/senapk/mula.git 
```

## Local install

```bash
pip install mula

## se aparecerem mensagens que a pasta ~/.local/bin não está no PATH
echo "export PATH=$PATH:~/.local/bin" >> ~/.bashrc
```
